@@ -8,7 +8,7 @@
 #' For both main and interaction calculation, the output can be filtered by p-values, such that only sets with smaller p-value
 #' than a threshold (\code{output.pval}) will be returned. An extension of the W-test for rare variant analysis is available in \code{zfa} package.}
 #' @param data a data frame or matrix containing genotypes in the columns. Genotypes should be coded as (0, 1, 2) or (0, 1).
-#' @param y a numeric vector of 0 or 1, or a factor variable with two levels.
+#' @param y a numeric vector of 0 or 1.
 #' @param w.order an integer value of 0 or 1. \code{w.order} = 1 for main effect calculation; \code{w.order} = 2 for pairwise calculation.
 #' @param hf1 \emph{h} and \emph{f} values to calculate main effect, organized as a matrix, with columns (\emph{k}, \emph{h}, \emph{f}), \emph{k} = 2 to 3. Needed when \code{w.order} = 1.
 #' @param hf2 \emph{h} and \emph{f} values to calculate interaction associations, organized as a matrix, with columns (\emph{k}, \emph{h}, \emph{f}), \emph{k} = 2 to 9. Needed when \code{w.order} = 2.
@@ -80,10 +80,15 @@ wtest<-function(data, y, w.order = c(1,2), hf1="default.hf1", hf2="default.hf2",
     stop("NA occurs in data")
   if(!all(data %in% c(0,1,2)))
     stop("all the genotypes in 'data' must be 0, 1 or 2")
+  if(any(is.na(y)))
+    stop("NA occurs in y")
+  if(!all(y %in% c(0,1)))
+    stop("all the genotypes in 'y' must be 0 or 1")
   if(!is.null(which.marker) & length(which.marker)!=w.order)
     stop(gettextf("the length of 'which.marker' is %d, should equal to %d (the number of 'w.order' defined)",length(which.marker),w.order))
   if(length(y)!=nrow(data))
     stop("'data' and 'y' must have the same length")
+  cl <- match.call()
   n.snp <- ncol(data)
   if(!is.null(which.marker)){
     set <- list(which.marker)
@@ -153,5 +158,5 @@ wtest<-function(data, y, w.order = c(1,2), hf1="default.hf1", hf2="default.hf2",
   hf1 <- cbind(k, hf1)
   k <- c(2:(nrow(hf2) + 1))
   hf2 <- cbind(k, hf2)
-  return(list(order = w.order, results = result.all, hf1 = hf1, hf2 = hf2))
+  return(list(call = cl, order = w.order, results = result.all, hf1 = hf1, hf2 = hf2))
 }
