@@ -3,13 +3,14 @@
 #' p-value than the threshold (\code{output.pval}) will be returned.}
 #' @param geno a data frame or matrix containing genotypes in the columns and subjects in the rows. Genotypes should be coded as (0, 1, 2) or (0, 1). SNP names should be stored as column names of the data.
 #' @param meth a data frame or matrix containing methylation data in the columns. Methylation data should be recoded as (0, 1, 2) or (0, 1). Names of CpG sites should be stored as column names of the data.
-#' @param y a numeric vector of 0 or 1; or a factor variable with two levels.
+#' @param y a numeric vector of 0 or 1.
 #' @param geno.pos a data frame containing SNP names and positions in two columns.
 #' @param meth.pos a data frame containing CpG names and positions in two columns.
 #' @param window.size a numeric number specifying the size of genome distance. Interaction effects of the SNPs and CpG sites located within the size of genome distance will be evaluated exhaustively.
 #' @param hf \emph{h} and \emph{f} values to calculate gene-methylation interaction associations, organized as a matrix, with columns (\emph{k}, \emph{h}, \emph{f}), \emph{k} = 2 to 6.
 #' @param output.pval a p-value threshold for filtering the output. If NULL, all results will be listed; otherwise, the function will only output the results with p-values smaller than \code{output.pval}.
 #' @param sort a logical value indicating whether or not to sort the output by p-values in ascending order. Default = TRUE.
+#' @param which.marker a vector indicating the column index of a SNP-CpG pair to calculate. Default \code{which.marker} = NULL means interaction pairs located within \code{window.size} will be calculated exhaustively.
 #' @return An object \code{"wtest.snps.meth"} containing:
 #'
 #' \item{results}{The test results include: SNP name, CpG name, SNP position, CpG position, W value, \emph{k}, and p-value.}
@@ -48,7 +49,7 @@
 #' @importFrom stats pchisq
 
 wtest.snps.meth <- function(geno, meth, y, geno.pos, meth.pos, window.size = 1e4, hf = "default.hf",
-                    output.pval = NULL, sort = TRUE){
+                    output.pval = NULL, sort = TRUE, which.marker = NULL){
   suppressWarnings(if(typeof(hf) == "character"){hf = array(c(0.5,0.667,0.75,0.8,0.833,0.857,0.875,0.889,1:8), dim = c(8,2))}else{hf = hf[,2:3]})
   if(is.data.frame(geno))
     geno <- as.matrix(geno)
@@ -60,9 +61,13 @@ wtest.snps.meth <- function(geno, meth, y, geno.pos, meth.pos, window.size = 1e4
     stop("NA occurs in data.methylation")
   if(!all(geno %in% c(0,1,2)))
     stop("all the genotypes in 'data.genotype' must be 0, 1 or 2")
+  if(any(is.na(y)))
+    stop("NA occurs in y")
+  if(!all(y %in% c(0,1)))
+    stop("all the genotypes in 'y' must be 0 or 1")
   if(length(y)!=nrow(geno) || nrow(meth)!=nrow(geno))
     stop("'data.genotype', 'data.methylation' and 'y' must have the same length")
-
+  cl <- match.call()
   snp.names <- colnames(geno)
   cpg.names <- colnames(meth)
   l1 <- match(snp.names, geno.pos[,1])
@@ -74,15 +79,19 @@ wtest.snps.meth <- function(geno, meth, y, geno.pos, meth.pos, window.size = 1e4
   geno.pos <- geno.pos[l1,]
   meth.pos <- meth.pos[l2,]
 
-  index.set<-data.frame()
-  for(i in 1:nrow(geno.pos)){
-    index <- which(abs(geno.pos[,2][i] - meth.pos[,2]) <= window.size)
-    if(length(index)){
-      index.i <- cbind(i, index)
-      index.set <- rbind(index.set, index.i)
+  if(!is.null(which.marker)){
+    set <- list(which.marker)
+  }else{
+    index.set<-data.frame()
+    for(i in 1:nrow(geno.pos)){
+      index <- which(abs(geno.pos[,2][i] - meth.pos[,2]) <= window.size)
+      if(length(index)){
+        index.i <- cbind(i, index)
+        index.set <- rbind(index.set, index.i)
+      }
     }
+    set <- apply(index.set, 1, list)
   }
-  set <- apply(index.set, 1, list)
 
   n.snp <- ncol(geno)
   n.cpg <- ncol(meth)
@@ -116,5 +125,5 @@ wtest.snps.meth <- function(geno, meth, y, geno.pos, meth.pos, window.size = 1e4
   k <- c(2:(nrow(hf)+1))
   hf <- cbind(k,hf)
   colnames(hf)<-c("k","h","f")
-  return(list(results = result.all, hf = hf))
+  return(list(call = cl, results = result.all, hf = hf))
 }
